package com.fs.wx.cp.service;

import com.alibaba.fastjson.JSONObject;
import com.fs.common.core.redis.RedisCache;
import com.fs.common.utils.spring.SpringUtils;
import com.fs.qywx.domain.QywxCustomUser;
import com.fs.qywx.domain.QywxUser;
import com.fs.wx.cp.config.QywxCacheConfig;
import com.fs.wx.cp.config.QywxThirdConfig;
import com.fs.wx.util.RestUtils;
import io.swagger.models.auth.In;
import org.apache.commons.collections4.Get;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;

import java.util.*;

@SuppressWarnings("all")
@Service
public class QywxUserUtil {
    private final static Logger logger = LoggerFactory.getLogger("test");

    QywxThirdConfig qywxThirdConfig=new QywxThirdConfig();
    QywxCacheConfig qywxCacheConfig= new QywxCacheConfig();
//    @Autowired
//    private QywxThirdConfig qywxThirdConfig;
//    @Autowired
//    private QywxCacheConfig qywxCacheConfig;
    @Autowired
    RedisCache redisCache;

    //获取客户列表
    public List getExtContactList(String userId,String accessToken){
        String url = String.format(qywxThirdConfig.getExtContactListUrl(),accessToken,userId);
        Map response = RestUtils.get(url);
        //获取错误日志
        if(response.containsKey("errcode") && (Integer) response.get("errcode") != 0){
            logger.error(response.toString());
            return null;
        }
        List ids = (List) response.get("external_userid");
        return ids;
    }

    //获取单个客户详情
    public Map getExtContactInfo(String userId,String accessToken){
        String url = String.format(qywxThirdConfig.getExtContactInfoUrl(),accessToken,userId,"500");
        Map response = RestUtils.get(url);
        //获取错误日志
        if(response.containsKey("errcode") && (Integer) response.get("errcode") != 0){
            logger.error(response.toString());
            return null;
        }
        return response;
    }
    //获取客户列表带详情
    public List<QywxCustomUser> getExtContactInfoList(List userIdList,String accessToken){
        String url = String.format(qywxThirdConfig.getExtContactInfoListUrl(),accessToken);
        JSONObject postJson = new JSONObject();
        postJson.put("userid_list",userIdList);
        postJson.put("limit",100);
        Map response = RestUtils.post(url,postJson);
        //获取错误日志
        if(response.containsKey("errcode") && (Integer) response.get("errcode") != 0){
            logger.error(response.toString());
            return null;
        }
        List<Map> externalContactList = (List) response.get("external_contact_list");
        ArrayList<QywxCustomUser> qwUser = new ArrayList<>();
        for (Map user : externalContactList) {
            System.out.println(user);
            Map m = (Map)user.get("follow_info");
            QywxCustomUser u = new QywxCustomUser();
            System.out.println((String) m.get("userid"));
            u.setUserid((String) m.get("userid"));

            System.out.println(u);
            u.setRemark((String) m.get("remark"));
            u.setDescription((String)m.get("description"));
            List<String> tag = (List<String>) m.get("tag_id");
            u.setTagId(tag.toString());
            List<String> mobiles = (List<String>) m.get("remark_mobiles");
            u.setRemarkMobiles(mobiles.toString());
            u.setRemarkCorpName((String)m.get("remark_corp_name"));
            u.setAddWay((Integer) m.get("add_way"));
            u.setOperUserid((String)m.get("oper_userid"));
            Map external = (Map)user.get("external_contact");
            System.out.println(external);
            u.setExternalUserid((String)external.get("external_userid"));
            u.setName((String)external.get("name"));
            u.setType((Integer)external.get("type"));
            qwUser.add(u);
        }
        return qwUser;
    }
    //修改备注信息
    public Boolean updateExtContactInfo(String accessToken){
        String url = String.format(qywxThirdConfig.getUpdateExtContactInfoListUrl(),accessToken);
        JSONObject postJson = new JSONObject();
        postJson.put("userid","ZhuangXu");
        postJson.put("external_userid","wm-YxDcgAA9PUhpOViiMgiqQ-ZgsJP_A");
        postJson.put("remark","HE");
        postJson.put("description","描述信息de 描述信息");
        postJson.put("remark_company","备注的企业XX企业");
        postJson.put("remark_mobiles", Arrays.asList("17302557022"));
        Map response = RestUtils.post(url,postJson);
        //获取错误日志
        if(response.containsKey("errcode") && (Integer) response.get("errcode") != 0){
            logger.error(response.toString());
            return false;
        }
        return true;
    }
    //获取企业标签
    public List getCorpTagListUrl(String accessToken){
        String url = String.format(qywxThirdConfig.getCorpTagListUrl(),accessToken);
        JSONObject postJson = new JSONObject();
        postJson.put("limit",100);
        Map response = RestUtils.post(url,null);
        //获取错误日志
        if(response.containsKey("errcode") && (Integer) response.get("errcode") != 0){
            logger.error(response.toString());
            return null;
        }
        List corpTagList = (List) response.get("tag_group");
        return corpTagList;
    }


    //获取可见部门所有用户
    public Map<String,QywxUser> getUserList(String accessToken,String corpId){
        String url = String.format(qywxThirdConfig.getDepartmentID(),accessToken);
        Map response = RestUtils.get(url);
        //获取错误日志
        if(response.containsKey("errcode") && (Integer) response.get("errcode") != 0){
            logger.error(response.toString());
            return null;
        }
        List<Map> corpTagList = (List) response.get("department_id");
        HashMap<String, QywxUser> Map = new HashMap<>();
        for (Map m : corpTagList) {
            Integer id = (Integer) m.get("id");
            String urlU = String.format(qywxThirdConfig.getDepartmentUser(),accessToken,id);
            Map re = RestUtils.get(urlU);
            if(re.containsKey("errcode") && (Integer) response.get("errcode") != 0){
                logger.error(re.toString());
            }
            List<Map> userlist = (List)re.get("userlist");
            if (userlist!=null){
                for (Map mp : userlist) {
                    QywxUser qywxUser = new QywxUser();
                    qywxUser.setUserId((String)mp.get("userid"));
                    qywxUser.setName((String)mp.get("name"));
                    qywxUser.setAvatar((String)mp.get("avatar"));
                    qywxUser.setOpenUserid((String)mp.get("open_userid"));
                    qywxUser.setMainDepartment((Integer) mp.get("main_department"));
                    qywxUser.setCorpId(corpId);
                    qywxUser.setStatus(1);
                    Map.put((String)mp.get("name"),qywxUser);
                }
            }


        }
        return Map;
    }
//获取配置了外部联系人的用户
    public List<String> getFollowUserList(String accessToken) {
        String url = String.format(qywxThirdConfig.getExtContactFollowUserListUrl(), accessToken);
        Map response = RestUtils.get(url);
        //获取错误日志
        if (response.containsKey("errcode") && (Integer) response.get("errcode") != 0) {
            logger.error(response.toString());
            return null;
        }
        return (List<String>) response.get("follow_user");
    }




}

//为客户修改企业标签
