package com.fs.app.controller;


import cn.hutool.json.JSONUtil;
import com.fs.app.annotation.Login;
import com.fs.app.vo.IndexVO;
import com.fs.common.core.domain.R;
import com.fs.store.domain.FsMenu;
import com.fs.store.domain.FsStoreCanvas;
import com.fs.store.param.*;
import com.fs.store.service.*;
import com.fs.store.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.Cacheable;

import javax.servlet.http.HttpServletRequest;
import java.util.List;


@Api("首页接口")
@RestController
@RequestMapping(value="/app/index")
public class IndexController extends AppBaseController {

	@Autowired
	private IFsArticleCateService articleCateService;

	@Autowired
	private IFsAdvService advService;

	@Autowired
	private IFsStoreProductService productService;



	@Autowired
	private IFsArticleService articleService;

	@Autowired
	private IFsStoreCartService cartService;
	@Autowired
	private IFsMenuService menuService;
	@Autowired
	private IFsStoreCanvasService storeCanvasService;
	@ApiOperation("获取首页数据")
	@GetMapping("/getIndexData")
	public R getIndexData(HttpServletRequest request){
		List<FsArticleCateListQueryVO> articleCateList=articleCateService.selectFsArticleCateListQuery();
		List<FsAdvListQueryVO> advList=advService.selectFsAdvListQuery(1);
		List<FsStoreProductListQueryVO> newProductList=productService.selectFsStoreProductNewQuery(10);
		List<FsStoreProductListQueryVO> hotProductList=productService.selectFsStoreProductHotQuery(10);
		IndexVO vo=IndexVO.builder().articleCateList(articleCateList).advList(advList).newProductList(newProductList).hotProductList(hotProductList).build();
		return R.ok().put("data", vo);
	}




	@ApiOperation("读取菜单数据")
	@GetMapping("/getMenu")
	@Cacheable("menu")
	public R getMenu(HttpServletRequest request){
		FsMenu map=new FsMenu();
		map.setIsShow(1);
		List<FsMenu> list=menuService.selectFsMenuList(map);
		return R.ok().put("data",list);
	}


	@ApiOperation("读取画布数据")
	@GetMapping("/getCanvas")
	@Cacheable("canvas")
	public R getCanvas(HttpServletRequest request){
		FsStoreCanvas map=new FsStoreCanvas();
		map.setIsDel(0);
		map.setType(1);
		List<FsStoreCanvas> canvas=storeCanvasService.selectFsStoreCanvasList(map);
		return R.ok().put("data", canvas.get(0));
	}



	@ApiOperation("获取推荐健康知识")
	@GetMapping("/getTuiArticle")
	public R getTuiArticle(FsArticleQueryParam param){

		List<FsArticleListQueryVO> list=articleService.selectFsArticleListQuery(param);
		return R.ok().put("data", list);
	}


	@Login
	@ApiOperation("获取购物车数量")
	@GetMapping("/getCartCount")
	public R getCartCount(){
		Integer count=cartService.selectFsStoreCartCountByUserId(Long.parseLong(getUserId()));
		return R.ok().put("data", count);
	}


}
